@@ -36,39 +36,41 @@
   if(add.axis) {axis(axis.pos, padj=axis.padj, tck=axis.tck)}
 }
 
-profitMakePlots <- function(image, modelimage, region, sigma, errischisq = FALSE,
+profitMakePlots <- function(image, modelimage, region, sigma, errischisq = FALSE, maxsigma=5,
   cmap = rev(colorRampPalette(brewer.pal(9,'RdYlBu'))(100)), 
   errcmap = rev(c("#B00000",colorRampPalette(brewer.pal(9,'RdYlBu'))(100)[2:99],"#0000B0")),
-  plotchisq=FALSE, dofs) {
+  plotchisq=FALSE, dofs, skewtparm = NULL) {
   residual = image - modelimage
   error=sigma
   
   parmar = par("mar")
   
+  medimg = median(abs(image[image>0 & region]))
+  maximg = max(abs(image[region]))
+  
+  stretchscale = 1/medimg
+    
   if(!plotchisq)
   {
     par(mar=c(0,0,0,0),oma=c(4.1,4.1,1.1,1.1))
     layout(cbind(1,2,3,4))
     
-    tempmap=magmap(image,lo=0,hi=1)$datalim
-    tempmap=max(abs(tempmap))
-    
-    magimage(image,stretchscale=1/median(abs(image[image>0])),lo=-tempmap,hi=tempmap,type='num',zlim=c(0,1),col=cmap,xlab='x/pix',ylab='y/pix')
+    magimage(image,stretchscale=stretchscale,locut=-maximg,hicut=maximg,type='num',zlim=c(0,1),col=cmap,xlab='x/pix',ylab='y/pix')
     if(missing(region)==FALSE & all(region)==FALSE){
-      tempcon=magimage(1-region,add=T,magmap=F,zlim=c(0,1),col=NA)#hsv(s=0,alpha=0.5)
-      contour(tempcon,add=T,drawlabels = F,levels=1,col='darkgreen')
+      tempcon=magimage(1-region,add=TRUE,magmap=FALSE,zlim=c(0,1),col=NA)#hsv(s=0,alpha=0.5)
+      contour(tempcon,add=TRUE,drawlabels=FALSE,levels=1,col='darkgreen')
     }
     legend('topleft',legend='Data')
     
-    magimage(modelimage,stretchscale=1/median(abs(image[image>0])),lo=-tempmap,hi=tempmap,type='num',zlim=c(0,1),col=cmap,xlab='x/pix')
+    magimage(modelimage,stretchscale=stretchscale,locut=-maximg,hicut=maximg,type='num',zlim=c(0,1),col=cmap,xlab='x/pix')
     if(missing(region)==FALSE & all(region)==FALSE){
-      contour(tempcon,add=T,drawlabels = F,levels=1,col='darkgreen')
-      legend('topleft',legend='Model')
+      contour(tempcon,add=TRUE,drawlabels=FALSE,levels=1,col='darkgreen')
     }
+    legend('topleft',legend='Model')
     
-    magimage(residual,stretchscale=1/median(abs(image[image>0])),lo=-tempmap,hi=tempmap,type='num',zlim=c(0,1),col=errcmap,xlab='x/pix')
+    magimage(residual,stretchscale=stretchscale,locut=-maximg,hicut=maximg,type='num',zlim=c(0,1),col=errcmap,xlab='x/pix')
     if(missing(region)==FALSE & all(region)==FALSE){
-      contour(tempcon,add=T,drawlabels = F,levels=1,col='darkgreen')
+      contour(tempcon,add=TRUE,drawlabels=FALSE,levels=1,col='darkgreen')
       legend('topleft',legend='Data-Model')
     }
     
@@ -80,38 +82,30 @@ profitMakePlots <- function(image, modelimage, region, sigma, errischisq = FALSE
   }
   else
   {
-    maxsigma = 5
     if(missing(dofs)){ndofs=0}else{ndofs = length(dofs)}
     if(ndofs>0) stopifnot(length(dofs) <= 2)
 
-    parmar2=c(1.5,2,0.5,0)
+    parmar2=c(3.5,3.5,0.5,0)
     par(mar=parmar2)
 
     layout(rbind(c(1,2,3,5),c(7,8,4,6)),widths=c(0.31,0.31,0.31,0.07),heights=c(0.5,0.5))
     
-    medimg = median(abs(image[region]))/2
-    maximg = max(abs(image[region]))
-    
-    zlims = c(0,1)
-    stretch="asinh"
-    stretchscale = 1/medimg
-    
-    magimage(image,stretchscale=stretchscale,stretch=stretch,lo=-maximg,hi=maximg,zlim=zlims,type='num',col=cmap)
+    magimage(image,stretchscale=stretchscale,locut=-maximg,hicut=maximg,type='num',zlim=c(0,1),col=cmap,xlab="x/pix",ylab="y/pix")
     if(missing(region)==FALSE & all(region)==FALSE){
-      tempcon=magimage(1-region,add=T,magmap=F,zlim=c(0,1),col=NA)#hsv(s=0,alpha=0.5)
-      contour(tempcon,add=T,drawlabels = F,levels=1,col='darkgreen')
+      tempcon=magimage(1-region,add=TRUE,magmap=FALSE,zlim=c(0,1),col=NA)#hsv(s=0,alpha=0.5)
+      contour(tempcon,add=TRUE,drawlabels = FALSE,levels=1,col='darkgreen')
     }
     legend('topleft',legend='Data')
     
-    magimage(modelimage,stretchscale=stretchscale,stretch=stretch,lo=-maximg,hi=maximg,zlim=zlims,type='num',col=cmap)
+    magimage(modelimage,stretchscale=stretchscale,locut=-maximg,hicut=maximg,type='num',zlim=c(0,1),xlab="x/pix",col=cmap)
     if(missing(region)==FALSE & all(region)==FALSE){
-      contour(tempcon,add=T,drawlabels = F,levels=1,col='darkgreen')
+      contour(tempcon,add=TRUE,drawlabels = FALSE,levels=1,col='darkgreen')
     }
     legend('topleft',legend='Model')
     
-    magimage(residual,stretchscale=stretchscale,stretch=stretch,lo=-maximg,hi=maximg,zlim=zlims,type='num',col=cmap)
+    magimage(residual,stretchscale=stretchscale,locut=-maximg,hicut=maximg,type='num',zlim=c(0,1),xlab="x/pix",col=errcmap)
     if(missing(region)==FALSE & all(region)==FALSE){
-      contour(tempcon,add=T,drawlabels = F,levels=1,col='darkgreen')
+      contour(tempcon,add=TRUE,drawlabels = FALSE,levels=1,col='darkgreen')
     }
     legend('topleft',legend='Data-Model')
       
@@ -125,19 +119,18 @@ profitMakePlots <- function(image, modelimage, region, sigma, errischisq = FALSE
     errmap = error
     error = error[region]
     maxerr = max(abs(error))
-    stretcherr = 1/median(abs(error))
     errmap[!region & (errmap>maxerr)] = maxerr
     minerr = -maxerr
     errmap[!region & (errmap<minerr)] = minerr
     errmap[errmap > maxsigma] = maxsigma
     errmap[errmap < -maxsigma] = -maxsigma
-    magimage(errmap,magmap=FALSE,zlim=c(-maxsigma,maxsigma),col=errcmap)
+    magimage(errmap,magmap=FALSE,zlim=c(-maxsigma,maxsigma),col=errcmap,xlab="x/pix")
     if(missing(region)==FALSE & all(region)==FALSE){
-      contour(tempcon,add=T,drawlabels = F,levels=1,col='darkgreen')
+      contour(tempcon,add=TRUE,drawlabels = FALSE,levels=1,col='darkgreen')
       legend('topleft',legend=bquote(chi*"=(Data-Model)"/sigma))
     }
     
-    par(mar=parmar2 + c(0,0,0,1))
+    par(mar=parmar2 + c(0,-1.5,0,1))
     pady=1
     breaks = seq(-maximg,maximg, length.out=length(cmap)+1)
     .profitImageScale(zlim=range(residuals), col=cmap, breaks = breaks, axis.pos=2, axis.padj=pady)
@@ -147,35 +140,42 @@ profitMakePlots <- function(image, modelimage, region, sigma, errischisq = FALSE
     par(mar=parmar2)
     ndat = sum(region)
     dx = 0.1
-    xlims = c(-4,4)
+    xlims = c(-5,5)
     x = seq(xlims[1],xlims[2],dx)
     y = hist(error,breaks=c(-(maxerr+dx),x,maxerr+dx),plot=FALSE)$count[2:length(x)]/ndat/dx
     ylim = c(min(y[y>0]),0.5)
-    y[y<=0] = ylim[1]-1
+    y[y<=0] = ylim[1]
     
     vardata = var(error)
     tdof=2*vardata/(vardata-1)
-    tdof=interval(tdof,0,Inf)
+    tdof=max(0, min(Inf, tdof, na.rm = TRUE), na.rm = TRUE)
   
-    magplot(x[1:(length(x)-1)]+dx,y, xlim=xlims, ylim=ylim, xlab="",ylab="", xaxs="i", type="s",log="y")
+    magplot(x, c(y,ylim[1]), xlim=xlims, ylim=ylim, xlab=expression(chi),
+      ylab="PDF", xaxs="i", yaxs="i", type="s",log="y")
     lines(x, dnorm(x), col="blue", xaxs="i")
     lines(x, dt(x,tdof), col="red", xaxs="i")
+    if(!is.null(skewtparm) && length(skewtparm) == 4) {
+      try(lines(x, sn::dst(x, dp = skewtparm), col="purple", xaxs="i"))
+    }
     
-    labs = c(expression(chi),bquote(norm(1)),bquote(Student-T(.(signif(tdof,5)))))
+    labs = c(expression(chi),bquote(norm(1)),bquote(Student-TRUE(.(signif(tdof,5)))))
     cols = c("black","blue","red")
     ltys = c(1,1,1)
-    legend("bottom",legend=labs,col=cols,lty=ltys)    
+    legend("bottom",legend=labs,col=cols,lty=ltys)
   
+    chisq = sum(error^2)/sum(region)
     error = log10(error^2)
     xr = range(error)
     xlims = c(-3,min(2,max(xr)))
     x = seq(xlims[1],xlims[2],dx)
     dxbin = 10^x[2:length(x)]-10^x[1:(length(x)-1)]
-    y = hist(error,breaks=c(xr[1]-dx,x,xr[2]+dx), plot=FALSE)$count[2:length(x)]
+    breaks=c(xr[1]-dx,x,xr[2]+dx)
+    y = hist(error,breaks=breaks, plot=FALSE)$count[2:length(x)]
     y = y/sum(y)/dxbin
     ylim = c(min(y[y>0]),10)
-    y[y<=0] = ylim[1]-1
-  magplot(x[1:(length(x)-1)]+dx, y, xlim=xlims,ylim=ylim, xlab="",ylab="", xaxs="i", type="s",log="y")
+    y[y<=0] = ylim[1]
+    magplot(x, c(y,ylim[1]), xlim=xlims,ylim=ylim, xlab=expression(log10(chi^2)),
+      ylab="", xaxs="i", type="s",log="y")
     xp=10^x
     lines(x, dchisq(xp,1), col="blue", xaxs="i")
     #lines(x, dt(xp,1), col="red", xaxs="i")
@@ -184,15 +184,16 @@ profitMakePlots <- function(image, modelimage, region, sigma, errischisq = FALSE
     if(ndofs > 0){
       dofcols = c("red","darkgreen")
       for(i in 1:length(dofs)){
-        dofstr = sprintf("%.3e",dofs[i])
+        dofstr = signif(dofs[i],5)
         lines(x, dchisq(xp,dofs[i]), col=dofcols[i], xaxs="i")
-        labs = c(labs,bquote(chi^2 (.(dofstr))))
+        labs = c(labs,bquote(chi^2*(.(dofstr))))
         ltys = c(ltys,1)
         cols = c(cols, dofcols[i])
       }
     }
     abline(v=0,lty=2,col='red')
     legend("bottomleft",legend=labs,col=cols,lty=ltys)
+    legend("topright",legend=bquote(chi[nu]^2*.(sprintf("=%.2f",chisq))),lty=NULL)
   }
   par(mar=parmar)
 }
\ No newline at end of file
